<?php
/**
 *  Fluistr Authentication
 *
 *  @class WPFluistrAuth
 *  @package fluistr-athentication
 *  @version 1.0.1
 */

if ( ! class_exists( 'WPFluistrAuth', false ) ) {

	/**
	 * Core Class WPFluistrAuth
	 */
	class WPFluistrAuth {

		private static $option_key = 'wp_fluistr';
		private static $modules    = array();
		private static $notices    = array();
		private static $options    = array();


		var $menu_slug   = WP_FLUISTR_SLUG;
		var $location_id = false;

		/**
		 * __construct
		 *
		 * @return void
		 */
		public function __construct() {
			 self::$options = get_option( self::$option_key );

			add_action( 'admin_notices', array( 'WPFluistrAuth', 'admin_notices' ) );
			add_action( 'admin_init', array( $this, 'admin_init' ) );
			add_action( 'init', array( $this, 'do_modules' ) );
		}

		static function get_option( $key ) {
			if ( isset( self::$options[ $key ] ) ) :
				return self::$options[ $key ];
			else :
				return '';
			endif;
		}
		static function get_options() {
			return self::$options;
		}

		static function update_option( $key, $value ) {
			if ( empty( $key ) ) {
				return false;
			}
			self::$options[ $key ] = $value;
			update_option( self::$option_key, self::$options );
			return self::$options;
		}

		static function update_options( $options ) {
			if ( ! is_array( $options ) ) {
				return false;
			}

			self::$options = $options;
			update_option( self::$option_key, self::$options );
			return self::$options;
		}

		static function delete_option( $key ) {
			if ( empty( $key ) || ! isset( self::$options[ $key ] ) ) {
				return false;
			}
			unset( self::$options[ $key ] );
			update_option( self::$option_key, self::$options );
			return self::$options;
		}

		static function stealth_modus() {
			return ! empty( self::get_option( 'stealth_modus', true ) );
		}


		static function AddModule( $name, $args ) {
			self::$modules[ $name ] = (object) array(
				'name'     => isset( $args['name'] ) ? $args['name'] : $name,
				'version'  => isset( $args['version'] ) ? $args['version'] : WP_FLUISTR_VERSION,
				'licensed' => isset( $args['licensed'] ) ? true : false,
				'slug'     => isset( $args['slug'] ) ? $args['slug'] : $name,
			);
		}

		static function getModules() {
			return self::$modules;
		}

		static function AddNotice( $message = 'missing notification message', $priority = 'error', $dismissible = false ) {
			self::$notices[] = array(
				'message'     => $message,
				'priority'    => $priority,
				'dismissible' => $dismissible,
			);
		}

		static function admin_notices() {
			if ( is_array( self::$notices ) && count( self::$notices ) > 0 ) :
				while ( count( self::$notices ) > 0 ) :
					$notice      = array_shift( self::$notices );
					$dismissible = $notice['dismissible'] ? ' is-dismissible' : '';
					printf( '<div class="%1$s"><p>%2$s</p></div>', 'notice notice-' . $notice['priority'] . $dismissible, $notice['message'] );
				endwhile;
			endif;
		}
		/**
		 * @since 2.0.1
		 * added folder namespacing
		 */

		public function do_modules() {
			do_action( 'wp_fluistr_modules' );
			do_action( 'wp_fluistr_init' );
		}


		static function uninstall() {
			delete_option( self::$option_key );
			delete_option( 'fluistr_activated' );
			delete_option( 'wp_fluistr_auth_version' );

			delete_site_option( self::$option_key );
			delete_site_option( 'fluistr_activated' );
			delete_site_option( 'wp_fluistr_auth_version' );

			self::deactivate_all_fluistr_users();

		}

		static function get_fluistr_html_template($filename='')
		{
			$html = '';
			$file = WP_FLUISTR_PLUGIN_DIR . '/modules/templates/' . $filename . '.html';
			if (is_file($file)):
				ob_start();
				include( $file);
				$html = ob_get_contents();
			ob_end_clean();
			endif;
			return $html;
		
		}

		static function get_total_fluistr_users() {
			global $total_fluistr_users;
			if ( is_numeric( $total_fluistr_users ) ) {
				return $total_fluistr_users;
			}

			$args = array(
				'meta_query'  => array(
					array(
						'key'     => 'fluistr_activated',
						'value'   => '1',
						'compare' => '=',
					),
				),
				'count_total' => true,
			);

			$users               = new WP_User_Query( $args );
			$total_fluistr_users = $users->get_total();
			return $total_fluistr_users;
		}


		static function deactivate_all_fluistr_users() {

			$all_user_ids = get_users( 'fields=ID' );
			foreach ( $all_user_ids as $user_id ) {
				delete_user_meta( $user_id, 'fluistr_init' );
				delete_user_meta( $user_id, 'fluistr_activated' );
				delete_user_meta( $user_id, 'fluistr_door' );
				delete_user_meta( $user_id, 'door_opened' );
				delete_user_meta( $user_id, 'door_expires' );
			}
		}



		static function missing_license_notice() {
			global $pagenow;
			if ( ( 'plugins.php' === $pagenow || ( 'options-general.php' === $pagenow && isset( $_GET['page'] ) && 'wpfluistr-settings' === $_GET['page'] ) || 'edit.php' === $pagenow ) ) {
				$message = __( 'Fluistr Authentication plugin is not activated.', 'fluistr-auth' );
				self::AddNotice( $message, 'warning', true );
			}
		}


		function admin_init() {
			if ( empty( self::get_option( 'fluistr_activated' ) ) && empty( $_POST['wp_fluistr']['fluistr_activated'] ) ) :
				self::AddNotice( wp_sprintf( __( 'Fluistr plugin is installed. For Fluistr to work, you have to complete the first %1$ssetup%2$s.' ), '<a href="admin.php?page=wpfluistr-settings#settings">', '</a>', 'fluistr-auth' ), 'warning', true );
				return;
			endif;

			if ( self::stealth_modus() ) :
				// hide profile password fields.
				add_filter( 'show_password_fields', '__return_false' );
			endif;
		}
	}

	/**
	 * Needed for license errors
	 */
	if ( ! function_exists( 'fa_add_notice' ) ) :
		/**
		 * Adds a notice.
		 *
		 * @param  string  $message as string.
		 * @param  string  $priority .
		 * @param  boolean $dismissible .
		 * @return void
		 */
		function fa_add_notice( $message = '', $priority = 'error', $dismissible = false ) {
			WPFluistrAuth::AddNotice( $message, $priority, $dismissible );
		}
	endif;
}
