<?php
/**
 *  Fluistr Authentication
 *
 *  @package fluistr-athentication
 *  @version 1.0.1
 *  @subpackage fluistr-settings
 */

/**
 *  Fluistr Authentication WPFluistrSettingsPage
 *
 *  @class WPFluistrSettingsPage
 *  @package fluistr-athentication
 *  @version 1.0.1
 *  @subpackage fluistr-settings
 */
class WPFluistrSettingsPage {

	/**
	 * Holds the values to be used in the fields callbacks
	 */
	const MENU_SLUG = 'wpfluistr-settings';
	var $tabs       = array();

	private static $sections = array();

	public static $default_options = array(
		'fluistr_activated' => '',
		'stealth_modus'     => '',
		'fluistr_uri'       => '',
		'license_key'       => '',
		'mail_login_info'   => "Username: *|USER_LOGIN|*\nCreate a secure Fluistr login for: *|BLOGNAME|*",

		// basic.
		'name'              => 'Fluistr',
		'slug'              => 'fluistr-authentication',
		'house'             => 'fluistr',
		'expires'           => 120,

		// options.
		'show_admin'        => true,
		'show_updates'      => true,
		'capability'        => 'manage_options',


	);

	/**
	 * Start up
	 */
	public function __construct() {
		$this->update_check( WP_FLUISTR_VERSION );
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'admin_init', array( $this, 'save_settings' ) );
		add_action( 'admin_init', array( $this, 'load_sections' ) );

		add_filter( 'plugin_action_links_' . WP_FLUISTR_PLUGIN_BASENAME, array( $this, 'add_action_links' ) );

	}

	/**
	 * Add options page
	 */
	public function admin_menu() {

		$capability = apply_filters( 'fluistr_manager_cap', 'manage_options' );
		add_menu_page(
			'Settings Fluistr Authentication',
			'Fluistr',
			$capability,
			self::MENU_SLUG,
			array( $this, 'print_admin_page' ),
			plugins_url( '/modules/fluistr-login/assets/images/icon-fluistr-menu.svg', WP_FLUISTR_PLUGIN_BASENAME ),
			50
		);

		$this->tabs   = array(
			array(
				'title'     => __( 'Dashboard', 'fluistr-auth' ),
				'slug'      => 'dashboard',
				'view_file' => 'dashboard.php',
				'icon'      => 'dashicons-dashboard',
			),
		);
		$this->tabs[] = array(
			'title'     => __( 'Settings', 'fluistr-auth' ),
			'slug'      => 'settings',
			'view_file' => 'settings.php',
			'icon'      => 'dashicons-admin-settings',
		);
		$this->tabs[] = array(
			'title'     => __( 'Extra', 'fluistr-auth' ),
			'slug'      => 'extra',
			'view_file' => 'extra.php',
			'icon'      => 'dashicons-editor-help',
		);

		foreach ( $this->tabs as $tab ) :
			add_submenu_page(
				self::MENU_SLUG,
				$tab['title'],
				$tab['title'],
				$capability,
				self::MENU_SLUG . '&section=settings#' . $tab['slug'],
				array( $this, 'print_admin_page' )
			);
		endforeach;
	}


	public function enqueue_scripts( $hook ) {

		wp_enqueue_style(
			'wpfluistr-settings',
			plugins_url( '/modules/fluistr-settings/assets/fluistr-settings.css', WP_FLUISTR_PLUGIN_BASENAME ),
			null,
			time()
		);

		wp_enqueue_script(
			'wpfluistr-settings', // Handle.
			plugins_url( '/modules/fluistr-settings/assets/fluistr-settings.min.js', WP_FLUISTR_PLUGIN_BASENAME ),
			array( 'jquery' ),
			time(),
			true
		);
	}



	public function save_settings() {
		if ( ! self::IsWPFluistrSettingsPage() ) {
			return;
		}

		if ( ! isset( $_POST['option_page'] ) || $_POST['option_page'] != 'fluistr_option_group' ) {
			return;
		}

		if ( ! isset( $_POST['wpnonce_fluistrauth'] )
			|| ! wp_verify_nonce( $_POST['wpnonce_fluistrauth'], 'updating_fluistr_auth' )
		) {
			print 'Sorry, your nonce did not verify.';
			exit;
		}

		if ( ! empty( $_POST['action'] ) && $_POST['action'] == 'update' && ! empty( $_POST['wp_fluistr'] ) ) {
			$fluistr_options = $this->sanitize( $_POST['wp_fluistr'] );
			$fluistr_options = wp_parse_args( $fluistr_options, self::$default_options );

			WPFluistrAuth::update_options( $fluistr_options );

			add_filter( 'add_admin_notice', __( 'settings updated', 'fluistr-auth' ), 'success', true );
		}
	}

	static function IsWPFluistrSettingsPage() {
		global $pagenow;
		return ( $pagenow == 'admin.php' && isset( $_GET['page'] ) && $_GET['page'] == self::MENU_SLUG );
	}

	public function load_sections() {
		if ( ! self::IsWPFluistrSettingsPage() ) {
			return;
		}
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * Sanitize each setting field as needed
	 *
	 * @param array $input Contains all settings fields as array keys
	 */
	public function sanitize( $input ) {
		if ( empty( $input ) ) {
			$input = array();
		}
		$input = apply_filters( 'wp_fluistr_sanitize_settings_page', $input );

		$new_input = WPFluistrAuth::get_options();
		// unset boolean.
		$new_input['fluistr_activated'] = '';
		$new_input['stealth_modus']     = '';

		foreach ( $input as $key => $val ) {
			switch ( $key ) {
				case 'fluistr_activated':
				case 'stealth_modus':
					$new_input[ $key ] = $val == '1' ? '1' : '';
					break;
			}
		}
		return $new_input;
	}


	public function print_admin_page() {
		if ( isset( $_GET['reset'] ) ) :
			$fluistr_options = self::$default_options;
			WPFluistrAuth::update_options( $fluistr_options );
		endif;

		if ( isset( $_GET['reset_passwords'] ) ) :
			WPFluistrAuth::reset_password_all_users();
		endif;

		foreach ( $this->tabs as $key => $tab ) :
			self::register_section( $tab, ( $key * 10 ) );
		endforeach;

		do_action( 'wp_fluistr_register_settings_section' );
		include_once dirname( __FILE__ ) . '/views/container.php';
	}

	public function update_check( $version ) {
		if ( get_site_option( 'wp_fluistr_auth_version' ) != $version ) {

			$options = WPFluistrAuth::get_options();

			/* Is this the first install, then set all defaults to active */
			if ( empty( $options ) ) {
				$options = self::$default_options;
			}

			$options = wp_parse_args( $options, self::$default_options );

			WPFluistrAuth::update_options( $options );

			/* UPDATE DONE! */
			update_site_option( 'wp_fluistr_auth_version', $version );
		}
	}



	static function register_section( $section, $ord = 99 ) {
		while ( isset( self::$sections[ $ord ] ) ) {
			$ord++;
		}

		self::$sections[ $ord ] = $section;
	}

	static function print_sections( $output = true ) {
		ksort( self::$sections );
		foreach ( self::$sections as $section ) {
			$icon = ! empty( $section['icon'] ) ? 'data-icon="' . $section['icon'] . '"' : '';
			$slug = ! isset( $section['slug'] ) || in_array( $section['slug'], array( 'dashboard', 'settings', 'extra' ), true ) ? 'fluistr-settings' : $section['slug'];
			echo PHP_EOL;
			echo '<div class="sections-container" id="sections-' . $section['slug'] . '" title="' . esc_attr( ucfirst( __( $section['title'] ) ) ) . '" ' . $icon . '>';
			if ( ! empty( $section['view_file'] ) ) :
				include_once WP_FLUISTR_PLUGIN_DIR . '/modules/' . basename( $slug ) . '/views/' . basename( $section['view_file'] );
			endif;
			if ( ! empty( $section['html'] ) ) {
				echo esc_html( $section['html'] );
			}
			echo '</div>';
			echo PHP_EOL;
		}
	}



	function add_action_links( $links ) {
		$mylinks = array(
			'<a href="' . admin_url( 'admin.php?page=' . self::MENU_SLUG ) . '">' . __( 'Settings', 'fluistr-auth' ) . '</a>',
		);
		return array_merge( $links, $mylinks );
	}

}
