<?php
/**
 *  Fluistr Authentication Form fields
 *
 *  @class WPFluistrAuth
 *  @package fluistr-athentication
 *  @version 1.0.1
 *  @subpackage fluistr-settings
 */

if ( ! defined( 'ABSPATH' ) || ! class_exists( 'WPFluistrSettingsPage', false ) ) {
	exit;
}



function print_start_table_form() {
	?>
	<table class="form-table"><tbody>
	<?php
}

function print_end_table_form() {
	?>
	</tbody></table>
	<?php
}


function get_checkbox( $id, $label = '', $disabled = false ) {
	$value   = WPFluistrAuth::get_option( $id );
	$checked = isset( $value ) && $value == '1' ? true : false;

	if ( $checked ) {
		$add_check = 'checked="checked"';
	} else {
		$add_check = '';
	};
	return '<label><input type="checkbox" name="wp_fluistr[' . $id . ']" value="1" ' . $add_check . ' ' . ( $disabled ? 'disabled' : '' ) . '/>&nbsp;' . $label . '</label>';
}

function print_table_row( $title, $content, $message = '' ) {
	print '<tr><th>' . esc_html( $title ) . '</th>';
	print '<td>';
	print esc_html( $content );
	if ( ! empty( $message ) ) {
		print '<p class="description">' . esc_html( $message ) . '</p>';
	}
	print '</td></tr>';
}


function print_input_number( $id, $title, $label = '', $message = '' ) {
	$value    = WPFluistrAuth::get_option( $id );
	$input    = isset( $value ) && is_numeric( $value ) ? intval( $value ) : 12;
	$disabled = ! current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' disabled="disabled"' : '';
	$name     = current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' name="wp_fluistr[' . $id . ']"' : '';

	print '<tr><th>' . esc_html( $title ) . '</th>';
	print '<td><label><input type="number" min="2" max="14"' . $name . ' value="' . esc_attr( $input ) . '"' . $disabled . ' />&nbsp;' . esc_html( $label ) . '</label>';
	print '<p class="description">' . esc_html( $message ) . '</p>';
	print '</td></tr>';
}

function print_input_text( $id, $title, $label = '', $message = '', $placeholder = '' ) {
	$value    = WPFluistrAuth::get_option( $id );
	$disabled = ! current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' disabled="disabled"' : '';
	$name     = current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' name="wp_fluistr[' . $id . ']"' : '';

	print '<tr><th>' . esc_html( $title ) . '</th>';
	print '<td><label><input type="text" style="width:100%;max-width:600px" placeholder="' . esc_attr( $placeholder ) . '"' . $name . ' value="' . esc_attr( $value ) . '"' . $disabled . ' />' . esc_html( $label ) . '</label>';
	print '<p class="description">' . esc_html( $message ) . '</p>';
	print '</td></tr>';
}
function print_textarea( $id, $title, $label = '', $message = '', $placeholder = '' ) {
	$value = WPFluistrAuth::get_option( $id );

	$disabled = ! current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' disabled="disabled"' : '';
	$name     = current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' name="wp_fluistr[' . $id . ']"' : '';

	print '<tr><th>' . esc_html( $title ) . '</th>';
	print '<td><span class="description">' . esc_html( $message ) . '</span></td>';
	print '</tr><tr><td colspan=2>';
	print '<textarea style="display:block;width:100%;" placeholder="' . esc_attr( $placeholder ) . '"' . $name . ' ' . $disabled . ' />' . esc_textarea( $value ) . '</textarea>';
	print '</td></tr>';
}


function print_input_url( $id, $title, $label = '', $message = '', $placeholder = 'https://' ) {
	$value    = WPFluistrAuth::get_option( $id );
	$disabled = ! current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' disabled="disabled"' : '';
	$name     = current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ? ' name="wp_fluistr[' . $id . ']"' : '';

	print '<tr><th>' . esc_html( $title ) . '</th>';
	print '<td><label><input type="url" style="width:100%;max-width:600px" placeholder="' . esc_attr( $placeholder ) . '"' . $name . ' value="' . esc_attr( $value ) . '"' . $disabled . ' />' . esc_html( $label ) . '</label>';
	print '<p class="description">' . esc_html( $message ) . '</p>';
	print '</td></tr>';
}



function get_selectbox_legal( $id, $legals ) {
	$value = WPFluistrAuth::get_option( $id );

	$content = '<select name="wp_fluistr[' . $id . ']">';
	foreach ( $legals as $key => $title ) :
		$selected = ! empty( $value ) && $value === $key ? 'SELECTED' : '';
		$content .= '<option ' . $selected . ' value="' . $key . '">' . esc_html( $title ) . '</option>';
   endforeach;
	$content .= '</select>';
	return $content;
}
