<?php
/**
 *  Fluistr Authentication
 *
 *  @class WPFluistrAuth
 *  @package fluistr-athentication
 *  @version 1.0.1
 *  @subpackage fluistr-users
 */

if ( ! defined( 'WP_FLUISTR_SLUG' ) ) {
	exit; // Exit if accessed directly.
}

global $pagenow;
if ( ! empty( $pagenow ) && 'users.php' === $pagenow && current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) ) :

	function fluistr_user_enqueue() {
		wp_enqueue_style(
			'wpfluistr-user',
			plugins_url( '/modules/fluistr-users/assets/fluistr-users.css', WP_FLUISTR_PLUGIN_BASENAME ),
			null,
			time()
		);
	}

	/**
	 * The fluistr toggler script placed in the wp admin footer
	 *
	 * @return void
	 */
	function fluistr_user_toggle_script() {?>
		<script type="text/javascript">
		function fluistr_user_toggle(user_id)
		{
			var $btn = jQuery('#fluistr-btn-'+user_id+' .slider');
			$btn.addClass('changing');
			jQuery.getJSON(ajaxurl, {
				action: 'fluistr_users_toggle',
				value: $btn.hasClass('active')?'-1':'1',
				user_id: user_id,
				nonce: '<?php echo wp_create_nonce( 'fluistr-ajax-nonce' ); ?>',
			}, function(response) {
				$btn.removeClass('changing');
				if (response.updated)
				{
					if (!response.active)
					{
						$btn.removeClass('active');
					}else{
						$btn.addClass('active')
					}
				}else if (response.licensed === false)
				{
					alert('The free version of Fluistr is limited to one active user.\nPurchase the Pro version and enjoy the use of unlimited users!');
				}
			});
		}
		</script>
		<?php
	}

	add_action( 'admin_enqueue_scripts', 'fluistr_user_enqueue' );
	add_action( 'admin_footer', 'fluistr_user_toggle_script' );

endif;



add_action( 'wp_ajax_fluistr_users_toggle', 'fluistr_users_toggle' );

/**
 * Ajax toggle function. Toggles the users fluistr option on or off.
 *
 * @return void
 */
function fluistr_users_toggle() {

	if ( ! isset( $_REQUEST['nonce'] )
	|| ! wp_verify_nonce( $_REQUEST['nonce'], 'fluistr-ajax-nonce' ) ) {
		die( 'don\'t try to beat the nonce' );
	}

	$on      = isset( $_REQUEST['value'] ) && '1' === strval( $_REQUEST['value'] ) ? true : false;
	$user_id = isset( $_REQUEST['user_id'] ) ? intval( $_REQUEST['user_id'] ) : false;

	if ( ! current_user_can( apply_filters( 'fluistr_manager_cap', 'manage_options' ) ) || ! $user_id ) :
		wp_send_json( (object) array( 'updated' => false ) );
	endif;

	if ( $on && WPFluistrAuth::get_total_fluistr_users() >= 1 && ! defined( 'WP_FLUISTR_LICENSED' ) ) :

		wp_send_json(
			(object) array(
				'updated'  => false,
				'licensed' => false,
			)
		);
	endif;

	if ( $on ) :
		$success = update_user_meta( $user_id, 'fluistr_activated', '1' );
	else :
		delete_user_meta( $user_id, 'fluistr_activated' );
		$success = true;
	endif;

	wp_send_json(
		(object) array(
			'updated'  => $success ? true : false,
			'active'   => $on ? true : false,
			'total'    => WPFluistrAuth::get_total_fluistr_users(),
			'licensed' => defined( 'WP_FLUISTR_LICENSED' ) ? true : false,
		)
	);
}
