<?php
/**
 * Fluistr settings licence class
 * 
 *  You can find out more about this plugin at https://fluistr.com
 *  Copyright (c) 2006-2021 Virgial Berveling
 *
 *  @package fluistr-autentication
 *  @author Virgial Berveling
 *  @copyright 2006-2021
 *  @subpackage fluistr-license
 *
 * version: 1.0.0
 */


class FluistrLicense
{
    var $licenseManager;
    private static $license = false;


    public function __construct()
    {

        if (empty(WPFluistrAuth::get_option('fluistr_activated'))) return;
        $product = new FA_Product(array(
            'item_name'         => 'fluistr',
            'slug'              => WP_FLUISTR_SLUG,
            'sku'               => 'nl.freeamigos.fluistr.users.year999',
            'api_url'           => 'https://licenses.fluistr.com/api/fluistr',
            'text_domain'       => 'fluistr-auth',
            'license_page_url'  => 'https://fluistr.com/renew/',
            'tracking_url'      => '',
        ));


        $this->licenseManager = new FA_LicenseManager($product);

        if ($this->licenseManager->license_is_valid() ):
            define('WP_FLUISTR_LICENSED',$this->licenseManager->get_license_key());
            //require_once(WP_FLUISTR_PLUGIN_DIR.'/core/class.pluginUpdater.php');
        endif;

        self::updateLicense( $this->licenseManager);

        add_filter('admin_init',array($this,'admin_init'));
        add_filter('wp_fluistr_sanitize_settings_page',array($this,'fluistr_license_sanitize'));
    }

    static function updateLicense($lc) {
        self::$license = $lc;
        return self::$license;
    }


    static function getLicense() {
        return self::$license;
    }


    public function admin_init()
    {
        WPFluistrSettingsPage::register_section(
            array(
            'title'=>__('License', 'fluistr-auth'),
            'icon' => ' dashicons-admin-plugins',
            'slug'=>'license',
            'view_file'=>'license.php',
        ),30);
    
    }


    public function fluistr_license_sanitize( $input )
    {
        if (!isset($input['license_key'])) return $input;


        if (!empty($_POST['activate-license'])):
            $check = $this->licenseManager->get_api_availability();
            if ($check['availability'])
            {
                $this->licenseManager->set_license_key($input['license_key']);
                $this->licenseManager->activate_license();
                if ($this->licenseManager->license_is_valid() ):
                    define('WP_FLUISTR_LICENSED',$this->licenseManager->get_license_key());
                endif;
            }
        endif;
        if (!empty($_POST['deactivate-license'])):
            $check = $this->licenseManager->get_api_availability();
            if ($check['availability'])
            {
                $this->licenseManager->deactivate_license();
                WPFluistrAuth::deactivate_all_fluistr_users();
                wp_redirect('?page=wpfluistr-settings#license');
                die;
            }
        endif;
        return $input;
    }
}
